#ifndef _FTP_H_
#define _FTP_H_

#include <arpa/inet.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/msg.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <math.h>
#include <netinet/ip.h>
#include <netinet/in.h>
#include <netdb.h>
#include <netinet/in_systm.h>
#include <net/if.h>      
#include <net/if_arp.h>  
/* by simon at 23/9/25*/
//#include <stropts.h>
#include <asm/ioctls.h>
#include <stdarg.h>
/***************** Define Variables ******************/
#define FTP_PORT 21
#define FTP_TIME_OUT 120
#define FTP_BUFSIZE 4096


#ifndef FTP_DEBUG
	#define FTP_DEBUG 0
#endif

/***************** Public Functions ******************/
int ftp_open(char *remoteip);
int ftp_login(char *username,char *userpass);
int ftp_cwd(char *remotepath);
int ftp_putfile(char *localpath,char *filename);
int ftp_getfile(char *localpath,char *filename);
int ftp_quit();


#endif
